# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aiobalaboba']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8,<4.0']

extras_require = \
{':python_version < "3.8"': ['typing-extensions>=3.7.4.3,<5']}

setup_kwargs = {
    'name': 'aiobalaboba',
    'version': '2.0.0',
    'description': 'Asynchronous wrapper for Yandex Balaboba',
    'long_description': '# aiobalaboba\n\n[![CI](https://github.com/monosans/aiobalaboba/actions/workflows/ci.yml/badge.svg?branch=main&event=push)](https://github.com/monosans/aiobalaboba/actions/workflows/ci.yml)\n[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/monosans/aiobalaboba/main.svg)](https://results.pre-commit.ci/latest/github/monosans/aiobalaboba/main)\n[![codecov](https://codecov.io/gh/monosans/aiobalaboba/branch/main/graph/badge.svg)](https://codecov.io/gh/monosans/aiobalaboba)\n\nAsynchronous wrapper for [Yandex Balaboba](https://yandex.com/lab/yalm-en) ([Яндекс Балабоба](https://yandex.ru/lab/yalm)).\n\nSynchronous version [here](https://github.com/monosans/balaboba).\n\n## Disclaimer\n\nThe neural network doesn’t really know what it’s saying, so it can say absolutely anything. Don’t get offended if it says something that hurts your feelings. When sharing the texts, make sure they’re not offensive or violate the law.\n\n## Installation\n\n```bash\npython -m pip install aiobalaboba\n```\n\n## Usage example\n\n```python\nimport asyncio\n\nfrom aiobalaboba import Balaboba\n\n\nasync def main():\n    bb = Balaboba()\n\n    # Get text types\n    intros = await bb.intros(language="en")\n\n    # Get the first text type\n    intro = next(intros)\n\n    # Print Balaboba\'s response to the "Hello" query\n    response = await bb.balaboba("Hello", intro=intro.number)\n    print(response)\n\nasyncio.run(main())\n```\n\n## License\n\n[MIT](https://github.com/monosans/aiobalaboba/blob/main/LICENSE)\n',
    'author': 'monosans',
    'author_email': 'hsyqixco@protonmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/monosans/aiobalaboba',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from __future__ import annotations

import sys
from typing import Any, Dict, Generator, NamedTuple, Optional

from aiohttp import ClientSession

if sys.version_info < (3, 8):  # pragma: no cover
    from typing_extensions import Literal
else:  # pragma: no cover
    from typing import Literal


class Intro(NamedTuple):
    number: int
    name: str
    description: str


class Balaboba:
    """Asynchronous wrapper for Yandex Balaboba."""

    __slots__ = ("session",)

    def __init__(self, session: Optional[ClientSession] = None) -> None:
        """Asynchronous wrapper for Yandex Balaboba.

        Args:
            session: Instance of aiohttp.ClientSession. By default, a
                new instance is created for each request.
        """
        self.session = session

    async def intros(
        self, language: Literal["en", "ru"] = "ru"
    ) -> Generator[Intro, None, None]:
        """Get text types."""
        endpoint = "intros" if language == "ru" else "intros_eng"
        response = await self._get_response(method="GET", endpoint=endpoint)
        return (Intro(*intro) for intro in response["intros"])

    async def balaboba(self, query: str, *, intro: int) -> str:
        """Get an answer from Balaboba.

        Args:
            query: Text for Balaboba.
            intro: Text type number. You can get the list of types using
                the intros method.
        """
        response = await self._get_response(
            method="POST",
            endpoint="text3",
            json={"query": query, "intro": intro, "filter": 1},
        )
        return f"{response['query']}{response['text']}"

    async def _get_response(
        self,
        *,
        method: str,
        endpoint: str,
        json: Optional[Dict[str, Any]] = None,
    ) -> Any:
        if isinstance(self.session, ClientSession) and not self.session.closed:
            return await self._fetch(
                method=method,
                endpoint=endpoint,
                json=json,
                session=self.session,
            )
        async with ClientSession() as session:
            return await self._fetch(
                method=method, endpoint=endpoint, json=json, session=session
            )

    async def _fetch(
        self,
        *,
        method: str,
        endpoint: str,
        json: Optional[Dict[str, Any]],
        session: ClientSession,
    ) -> Any:
        async with session.request(
            method,
            f"https://yandex.ru/lab/api/yalm/{endpoint}",
            json=json,
            raise_for_status=True,
        ) as response:
            return await response.json()
